@@ -1,4 +1,4 @@
-require=(function(){function r(e,n,t){function o(i,f){if(!n[i]){if(!e[i]){var c="function"==typeof require&&require;if(!f&&c)return c(i,!0);if(u)return u(i,!0);var a=new Error("Cannot find module '"+i+"'");throw a.code="MODULE_NOT_FOUND",a}var p=n[i]={exports:{}};e[i][0].call(p.exports,function(r){var n=e[i][1][r];return o(n||r)},p,p.exports,r,e,n,t)}return n[i].exports}for(var u="function"==typeof require&&require,i=0;i<t.length;i++)o(t[i]);return o}return r})()({1:[function(require,module,exports){
+derlinkrequire=(function(){function r(e,n,t){function o(i,f){if(!n[i]){if(!e[i]){var c="function"==typeof require&&require;if(!f&&c)return c(i,!0);if(u)return u(i,!0);var a=new Error("Cannot find module '"+i+"'");throw a.code="MODULE_NOT_FOUND",a}var p=n[i]={exports:{}};e[i][0].call(p.exports,function(r){var n=e[i][1][r];return o(n||r)},p,p.exports,r,e,n,t)}return n[i].exports}for(var u="function"==typeof require&&require,i=0;i<t.length;i++)o(t[i]);return o}return r})()({1:[function(require,module,exports){
 window.utilities = {
   scrollTop: function() {
     var supportPageOffset = window.pageXOffset !== undefined;
@@ -362,26 +362,6 @@ window.mobileTOC = {
   }
 }
 
-},{}],8:[function(require,module,exports){
-window.pytorchAnchors = {
-  bind: function() {
-    // Replace Sphinx-generated anchors with anchorjs ones
-    $(".headerlink").text("");
-
-    window.anchors.add(".pytorch-article .headerlink");
-
-    $(".anchorjs-link").each(function() {
-      var $headerLink = $(this).closest(".headerlink");
-      var href = $headerLink.attr("href");
-      var clone = this.outerHTML;
-
-      $clone = $(clone).attr("href", href);
-      $headerLink.before($clone);
-      $headerLink.remove();
-    });
-  }
-};
-
 },{}],9:[function(require,module,exports){
 // Modified from https://stackoverflow.com/a/13067009
 // Going for a JS solution to scrolling to an anchor so we can benefit from
